
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

set(_qt5Concurrent_install_prefix "/usr/lib/qt5")

set(Qt5Concurrent_VERSION_MAJOR 5)
set(Qt5Concurrent_VERSION_MINOR 0)
set(Qt5Concurrent_VERSION_PATCH 2)
set(Qt5Concurrent_VERSION_STRING 5.0.2)

set(Qt5Concurrent_LIBRARIES Qt5::Concurrent)

macro(_populate_Concurrent_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::Concurrent APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set_target_properties(Qt5::Concurrent PROPERTIES
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5Concurrent_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" "/usr/lib/qt5/lib/${LIB_LOCATION}"
        "IMPORTED_SONAME_${Configuration}" "libQt5Concurrent.so.5"
    )
endmacro()

if (NOT TARGET Qt5::Concurrent)

    set(Qt5Concurrent_INCLUDE_DIRS "/usr/lib/qt5/include/QtConcurrent")
    set(Qt5Concurrent_PRIVATE_INCLUDE_DIRS
        "/usr/lib/qt5/include/QtConcurrent/${Qt5Concurrent_VERSION_STRING}"
        "/usr/lib/qt5/include/QtConcurrent/${Qt5Concurrent_VERSION_STRING}/QtConcurrent"
    )

    set(Qt5Concurrent_DEFINITIONS -DQT_CONCURRENT_LIB)
    set(Qt5Concurrent_COMPILE_DEFINITIONS QT_CONCURRENT_LIB)

    set(_Qt5Concurrent_MODULE_DEPENDENCIES "Core")

    set(_Qt5Concurrent_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5Concurrent_FIND_REQUIRED)
        set(_Qt5Concurrent_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5Concurrent_FIND_DEPENDENCIES_QUIET)
    if (Qt5Concurrent_FIND_QUIETLY)
        set(_Qt5Concurrent_DEPENDENCIES_FIND_QUIET QUIET)
    endif()

    foreach(_module_dep ${_Qt5Concurrent_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                ${_Qt5Concurrent_DEPENDENCIES_FIND_QUIET}
                ${_Qt5Concurrent_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${_qt5Concurrent_install_prefix}" NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5Concurrent_FOUND False)
            return()
        endif()

        list(APPEND Qt5Concurrent_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5Concurrent_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5Concurrent_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5Concurrent_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5Concurrent_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5Concurrent_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5Concurrent_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5Concurrent_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5Concurrent_COMPILE_DEFINITIONS)
    if (Qt5Concurrent_EXECUTABLE_COMPILE_FLAGS)
      list(REMOVE_DUPLICATES Qt5Concurrent_EXECUTABLE_COMPILE_FLAGS)
    endif()

    set(_Qt5Concurrent_LIB_DEPENDENCIES "Qt5::Core")

    add_library(Qt5::Concurrent SHARED IMPORTED)

    _populate_Concurrent_target_properties(RELEASE "libQt5Concurrent.so.5.0.2" "" )






endif()
